==> seq24_0.5.3.orig.tar.gz: seq24-0.5.3/src/perfroll.h <==
//----------------------------------------------------------------------------
//
//  This file is part of seq24.
//
//  seq24 is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  seq24 is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with seq24; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//-----------------------------------------------------------------------------


#ifndef SEQ24_PERFROLL
#define SEQ24_PERFROLL

#include <gtk--/button.h>
#include <gtk--/window.h>
#include <gtk--/accelgroup.h>
#include <gtk--/box.h>
#include <gtk--/main.h>
#include <gtk--/menu.h>
#include <gtk--/menubar.h>
#include <gtk--/eventbox.h>
#include <gtk--/window.h>
#include <gtk--/table.h>
#include <gtk--/drawingarea.h>
#include <gtk--/widget.h>
#include <gtk--/scrollbar.h>
#include <gtk--/adjustment.h> 

#include "globals.h"
#include "perform.h"
#include "mutex.h"


using namespace Gtk;
using SigC::slot;

/* performance roll */
class perfroll : public Gtk::DrawingArea
{

 private: 

    Gdk_GC       m_gc;
    Gdk_Window   m_window;
    Gdk_Color    m_black, m_white, m_grey;

    Gdk_Pixmap   m_pixmap;
    Gdk_Pixmap   m_background;


    perform        *m_mainperf;

    int          m_snap;

    int          m_window_x, 
	         m_window_y;
 
    long         m_old_progress_ticks;

    int          m_4bar_offset;
    int          m_sequence_offset;

    int          m_roll_length_ticks;

    Adjustment   *m_vadjust;
    Adjustment   *m_hadjust;

    bool m_adding;
    bool m_adding_pressed;
    bool m_adding_pressed_state;

    void realize_impl();
    int expose_event_impl(GdkEventExpose* a_ev);
    int button_press_event_impl(GdkEventButton* a_ev); 
    int button_release_event_impl(GdkEventButton* a_ev);
    int motion_notify_event_impl(GdkEventMotion* a_ev);

    int focus_in_event_impl(GdkEventFocus*);
    int focus_out_event_impl(GdkEventFocus*);

    void size_request_impl(GtkRequisition* );
    void size_allocate_impl(GtkAllocation* );

    void convert_xy( int a_x, int a_y, long *a_ticks, int *a_seq);
    void snap_x( int *a_x );

    void draw_sequence_on( Gdk_Drawable *a_draw, int a_sequence );
    void draw_background_at( Gdk_Drawable *a_draw, int a_x, long a_y );

    void change_horz( void );
    void change_vert( void );



 public:

    void set_snap( int a_snap );

    void update_sizes();
    void fill_background_pixmap();

    void increment_size();

    void draw_progress();

    void set_adding( bool a_adding );

    perfroll( perform *a_perf, 
	      Adjustment *a_hadjust,
	      Adjustment *a_vadjust );

    ~perfroll( );
};

#endif

==> seq24_0.6.3.orig.tar.gz: seq24-0.6.3/src/perfroll.h <==
//----------------------------------------------------------------------------
//
//  This file is part of seq24.
//
//  seq24 is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  seq24 is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with seq24; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//-----------------------------------------------------------------------------


#ifndef SEQ24_PERFROLL
#define SEQ24_PERFROLL

#include <gtkmm/button.h>
#include <gtkmm/window.h>
#include <gtkmm/accelgroup.h>
#include <gtkmm/box.h>
#include <gtkmm/main.h>
#include <gtkmm/menu.h>
#include <gtkmm/menubar.h>
#include <gtkmm/eventbox.h>
#include <gtkmm/window.h>
#include <gtkmm/table.h>
#include <gtkmm/drawingarea.h>
#include <gtkmm/widget.h>
#include <gtkmm/scrollbar.h>
#include <gtkmm/adjustment.h>
#include <gdkmm/cursor.h>

#include "globals.h"
#include "perform.h"
#include "mutex.h"


using namespace Gtk;
using SigC::slot;

/* performance roll */
class perfroll : public Gtk::DrawingArea
{

 private: 

    Glib::RefPtr<Gdk::GC> m_gc;
    Glib::RefPtr<Gdk::Window> m_window;
    Gdk::Color    m_black, m_white, m_grey;

    Glib::RefPtr<Gdk::Pixmap> m_pixmap;
    Glib::RefPtr<Gdk::Pixmap> m_background;


    perform        *m_mainperf;

    int          m_snap;

    int          m_window_x, m_window_y;
 
    long         m_old_progress_ticks;

    int          m_4bar_offset;
    int          m_sequence_offset;

    int          m_roll_length_ticks;

    Adjustment   *m_vadjust;
    Adjustment   *m_hadjust;

    bool m_adding;
    bool m_adding_pressed;
    bool m_adding_pressed_state;

    void on_realize();
    bool on_expose_event(GdkEventExpose* a_ev);
    bool on_button_press_event(GdkEventButton* a_ev); 
    bool on_button_release_event(GdkEventButton* a_ev);
    bool on_motion_notify_event(GdkEventMotion* a_ev);

    bool on_focus_in_event(GdkEventFocus*);
    bool on_focus_out_event(GdkEventFocus*);

    void on_size_request(GtkRequisition* );
    void on_size_allocate(GtkAllocation* );

    void convert_xy( int a_x, int a_y, long *a_ticks, int *a_seq);
    void snap_x( int *a_x );

    void draw_sequence_on( Glib::RefPtr<Gdk::Drawable> a_draw, int a_sequence );
    void draw_background_at( Glib::RefPtr<Gdk::Drawable> a_draw, int a_x, long a_y );

    void change_horz( void );
    void change_vert( void );



 public:

    void set_snap( int a_snap );

    void update_sizes();
    void fill_background_pixmap();

    void increment_size();

    void draw_progress();

    void set_adding( bool a_adding );

    perfroll( perform *a_perf, 
	      Adjustment *a_hadjust,
	      Adjustment *a_vadjust );

    ~perfroll( );
};

#endif
